const inquirer = require('inquirer')
// const shell = require('shelljs')
const chalk = require('chalk')
const fs = require('fs')
const path = require('path')

const generate = require('./index')

const templatePath = path.join(__dirname, '/template')
const templateNames = fs.readdirSync(templatePath)

let templates = []
for (let template of templateNames) {
  const pkg = require(`./template/${template}/package.json`)
  templates.push({
    template,
    name: pkg.name,
    description: pkg.description
  })
}


const questions = [
  {
    type: 'input',
    name: 'name',
    message: "What's your project name?",
    validate: (value) => {
      value = value.trim();
      if (!value) {
        return 'Project name could not be empty!';
      }
      if (/\s/g.test(value)) {
        return 'Project name could not have spacing！';
      }
      return true;
    }
  },
  {
    type: 'list',
    name: 'template',
    message: 'Which template will you choose?',
    choices: templates.map((item) => `${item.template} (${item.description})`),
    filter: (val) => {
      return val.toLowerCase();
    }
  },
  {
    type: 'input',
    name: 'path',
    message: 'What\'s path will your project stay?',
    validate: (value) => {
      value = value.trim();
      if (!value) {
        return 'Project name could not be empty!';
      }
      return true;
    }
  }
];

/**
 * prompt
 *  example: { name: 'project', template: 'pure', path: '/Users/fedor/tmp' }
 */
inquirer.prompt(questions).then((answers) => {
  const projectName = answers.name.trim()
  const projectStayPath = answers.path.trim()

  // confirm template name
  let templateName
  for(let item of templates) {
    if(answers.template.startsWith(item.template)) {
      templateName = item.template
      break
    }
  }
  if(!templateName) {
    return console.log(chalk.red(`! template not found :( `))
  }


  const r = generate(templateName, projectName, projectStayPath)
  if(r.status === 0) {
    return console.log(chalk.red(r.message))
  }
  console.log(chalk.green(`√ generate project succeed :) `))
});
